@@ -1,5 +1,5 @@
 utils::globalVariables(c("doc_id","uc","uce","segment_size","upos","noSingleChar",
-"token","lemma","freq","chi_square", "cluster", "negative", "positive", "term", "freq_true", "indep", "p_value","."))
+"token","lemma","freq","chi_square", "cluster", "negative", "positive", "term", "freq_true", "indep", "p_value",".", "segment"))
 
 
 #' Segment clustering based on the Reinert method - Simple clustering
@@ -20,7 +20,7 @@ utils::globalVariables(c("doc_id","uc","uce","segment_size","upos","noSingleChar
 #'
 #'
 #' @return
-#' The result is a list of both class `hclust` and `reinert_tall`. 
+#' The result is a list of both class `hclust` and `reinert_tall`.
 #'
 #' @references
 #'
@@ -29,7 +29,7 @@ utils::globalVariables(c("doc_id","uc","uce","segment_size","upos","noSingleChar
 #' - Barnier J., Privé F., rainette: The Reinert Method for Textual Data Clustering, 2023, \doi{10.32614/CRAN.package.rainette}
 #'
 #' @examples
-#' 
+#'
 #' \donttest{
 #' data(mobydick)
 #' res <- reinert(
@@ -43,7 +43,7 @@ utils::globalVariables(c("doc_id","uc","uce","segment_size","upos","noSingleChar
 #'   tsj = 3
 #' )
 #' }
-#' 
+#'
 #' @export
 #'
 
@@ -98,6 +98,11 @@ reinert <- function(
     summarize(segment = paste0(term,collapse = " ")) %>%
     as.data.frame()
 
+  corresp_uce_uc_full <- corresp_uce_uc_full %>%
+    group_by(uc) %>%
+    reframe(doc_id = doc_id[1],
+      segment = paste0(segment,collapse=" ")) %>% distinct() %>% data.frame()
+
   row.names(corresp_uce_uc_full) <- corresp_uce_uc_full$uc
 
   dtf <- document_term_frequencies(x, document="uc",term=colTerm)
@@ -446,11 +451,11 @@ merge_small_segments <- function(idTable, min_length=5) {
 #'   }
 #' }
 #'
-#' @details The function integrates document-term matrix rows for missing segments, calculates term statistics for each cluster, 
+#' @details The function integrates document-term matrix rows for missing segments, calculates term statistics for each cluster,
 #' and filters terms based on their significance. Terms can be excluded based on their significance (\code{signExcluded}).
 #'
 #' @examples
-#' 
+#'
 #' \donttest{
 #' data(mobydick)
 #' res <- reinert(
@@ -463,15 +468,15 @@ merge_small_segments <- function(idTable, min_length=5) {
 #'   cc_test = 0.3,
 #'   tsj = 3
 #' )
-#' 
+#'
 #' tc <- term_per_cluster(res, cutree = NULL, k=1:10, negative=FALSE)
-#' 
+#'
 #' head(tc$segments,10)
-#' 
+#'
 #' head(tc$terms,10)
-#' 
+#'
 #' }
-#' 
+#'
 #' @export
 
 term_per_cluster <- function(res, cutree=NULL, k=1, negative=TRUE){
@@ -507,11 +512,11 @@ term_per_cluster <- function(res, cutree=NULL, k=1, negative=TRUE){
       mutate(cluster = k)
     segments_list[[k]] <-segments_df
 
-    chi_res_df <- dtm_chisq(dtm, groups = select) %>% 
+    chi_res_df <- dtm_chisq(dtm, groups = select) %>%
       mutate(indep = sum(freq_true)/sum(freq)) %>%  # expected proportion for independence
-      mutate(cluster = k) %>% 
+      mutate(cluster = k) %>%
       rename("chi_square" = "chisq",
-        "p_value" = "p.value") 
+        "p_value" = "p.value")
 
     terms_list[[k]] <- chi_res_df
   }
@@ -524,13 +529,13 @@ term_per_cluster <- function(res, cutree=NULL, k=1, negative=TRUE){
     signExcluded <- c("none","negative")
   }
 
-  terms_list <- bind_rows(terms_list) %>% 
-    group_by(term) %>% 
-    mutate(freq = sum(freq_true)) %>% 
-    ungroup() %>% 
-    filter(p_value<=0.001) %>% 
+  terms_list <- bind_rows(terms_list) %>%
+    group_by(term) %>%
+    mutate(freq = sum(freq_true)) %>%
+    ungroup() %>%
+    filter(p_value<=0.001) %>%
     mutate(freq = freq_true/freq,
-           sign = ifelse(freq>indep,"positive","negative")) %>% 
+           sign = ifelse(freq>indep,"positive","negative")) %>%
       filter(!sign %in% signExcluded)
 
   segments_list <- bind_rows(segments_list) %>% drop_na("doc_id")
@@ -543,10 +548,10 @@ term_per_cluster <- function(res, cutree=NULL, k=1, negative=TRUE){
 
 #' Plot Terms by Cluster
 #'
-#' This function creates a horizontal bar plot to visualize the most significant terms 
+#' This function creates a horizontal bar plot to visualize the most significant terms
 #' for each cluster, based on their Chi-squared statistics.
 #'
-#' @param terms A data frame containing terms and their associated statistics, such as Chi-squared values, 
+#' @param terms A data frame containing terms and their associated statistics, such as Chi-squared values,
 #' generated by the `term_per_cluster` function. The data frame must include the following columns:
 #' \itemize{
 #'   \item \code{term}: The term to plot.
@@ -561,11 +566,11 @@ term_per_cluster <- function(res, cutree=NULL, k=1, negative=TRUE){
 #'   \item Hover information displaying the term and its Chi-squared value.
 #' }
 #'
-#' @details The function organizes the input data by Chi-squared values and selects the top terms for each sign. 
+#' @details The function organizes the input data by Chi-squared values and selects the top terms for each sign.
 #' The plot uses different colors for positive and negative terms, with hover tooltips providing detailed information.
 #'
 #' @seealso \code{\link{term_per_cluster}}
-#' 
+#'
 #' @examples
 #' \dontrun{
 #' data(mobydick)
@@ -579,25 +584,25 @@ term_per_cluster <- function(res, cutree=NULL, k=1, negative=TRUE){
 #'   cc_test = 0.3,
 #'   tsj = 3
 #' )
-#' 
+#'
 #' tc <- term_per_cluster(res, cutree = NULL, k=1, negative=FALSE)
-#' 
+#'
 #' fig <- reinPlot(tc$terms, nPlot = 10)
 #' }
-#' 
+#'
 #' @export
-#' 
+#'
 reinPlot <- function(terms, nPlot = 10) {
   # Separate positive and negative terms
   dfPositive <- terms %>%
     filter(sign == "positive") %>%
-    ungroup() %>% 
+    ungroup() %>%
     arrange(desc(chi_square)) %>%
     slice_head(n = nPlot)
 
   dfNegative <- terms %>%
     filter(sign == "negative") %>%
-    ungroup() %>% 
+    ungroup() %>%
     arrange(desc(chi_square)) %>%
     slice_head(n = nPlot)
 
@@ -644,7 +649,7 @@ reinPlot <- function(terms, nPlot = 10) {
 
 #' Summarize Reinert Clustering Results
 #'
-#' This function summarizes the results of the Reinert clustering algorithm, including the most frequent documents and significant terms for each cluster. 
+#' This function summarizes the results of the Reinert clustering algorithm, including the most frequent documents and significant terms for each cluster.
 #' The input is the result returned by the `term_per_cluster` function.
 #'
 #' @param tc A list returned by the \code{term_per_cluster} function. The list includes:
@@ -673,9 +678,9 @@ reinPlot <- function(terms, nPlot = 10) {
 #'
 #'
 #' @seealso \code{\link{term_per_cluster}}, \code{\link{reinPlot}}
-#' 
+#'
 #' @examples
-#' 
+#'
 #' \donttest{
 #' data(mobydick)
 #' res <- reinert(
@@ -688,48 +693,57 @@ reinPlot <- function(terms, nPlot = 10) {
 #'   cc_test = 0.3,
 #'   tsj = 3
 #' )
-#' 
+#'
 #' tc <- term_per_cluster(res, cutree = NULL, k=1:10, negative=FALSE)
-#' 
+#'
 #' S <- reinSummary(tc, n=10)
-#' 
+#'
 #' head(S, 10)
 #' }
-#' 
+#'
 #' @export
-#' 
+#'
 reinSummary <- function(tc, n=10){
-  segments <- tc$segments %>% 
-    group_by(cluster) %>% 
-    # summarise("Number of Segments" = n()) %>% 
-    # group_by(cluster) %>% 
+  segments <- tc$segments %>%
+    group_by(cluster) %>%
+    # summarise("Number of Segments" = n()) %>%
+    # group_by(cluster) %>%
     summarize("Most frequent document" = names(which.max(table(doc_id))),
               "N. of Segments per Cluster" = n()
     )
-  
-    terms <- tc$terms %>% 
-      group_by(cluster, sign) %>% 
-      slice_max(order_by = chi_square, n = 10, with_ties = TRUE) %>% 
+
+    terms <- tc$terms %>%
+      group_by(cluster, sign) %>%
+      slice_max(order_by = chi_square, n = 10, with_ties = TRUE) %>%
       summarize(terms = paste0(term, collapse = "; "), .groups = "drop") %>%
       pivot_wider(
-        names_from = sign, 
-        values_from = terms, 
+        names_from = sign,
+        values_from = terms,
         names_prefix = "",
         values_fill = list(terms = NA) # Riempie con NA se mancano valori
-      ) %>%
-      # Aggiunta esplicita delle colonne mancanti
-      mutate(
-        positive = ifelse("positive" %in% names(.), positive, ""), 
-        negative = ifelse("negative" %in% names(.), negative, "")
-      ) %>%
+      )
+
+    if (!"positive" %in% names(terms)){
+      terms$positive <- ""
+    } else {
+      terms$positive[is.na(terms$positive)] <- ""
+    }
+    if (!"negative" %in% names(terms)){
+      terms$negative <- ""
+    } else {
+      terms$negative[is.na(terms$negative)] <- ""
+    }
+
+      terms <- terms %>%
       rename(
-        "Positively Associated Terms" = positive, 
+        "Positively Associated Terms" = positive,
         "Negatively Associated Terms" = negative
       )
-  
-  summaryTable <- terms %>% 
+
+
+  summaryTable <- terms %>%
     left_join(segments, by = "cluster")
-  
+
   return(summaryTable)
 }
 
